Description: keema-architect == bread, flarchitect.architect == api Coverage Report GitHub License PyPI - Downloads GitHub Repo flarchitect automatically creates rapid, prototype or production ready API’s directly fr...

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# flarchitect

keema-architect == bread, flarchitect.architect == api

flarchitect automatically creates rapid, prototype or production ready API’s directly from SQLAlchemy models with accompanying Redoc documentation, all with little to no effort.

By adding flarchitect to your Flask application, you can be up and running in seconds, creating a fully functional RESTful API, with a plethora of configuration options to suit your needs.

What can it do?

- Automatically detect and create endpoints, with nested model relationships and more.

- Standardize your API responses with a consistent format.

- Authenticate users with a variety of methods.

- Add ratelimiting, caching and more with no work.

- Be configured globally in Flask or in your SQLAlchemy models.

- Automatically generate Redoc documentation.

What are you waiting for…?

Turn this.

    class Book(db.Model):

        id = db.Column(db.Integer, primary_key=True)
        title = db.Column(db.String(80), unique=True, nullable=False)
        author = db.Column(db.String(80), nullable=False)
        published = db.Column(db.DateTime, nullable=False)

Into this:

`GET /api/books`

    {
      "datetime": "2024-01-01T00:00:00.0000+00:00",
      "api_version": "0.1.0",
      "status_code": 200,
      "response_ms": 15,
      "total_count": 10,
      "next_url": "/api/authors?limit=2&page=3",
      "previous_url": "/api/authors?limit=2&page=1",
      "error": "null",
      "value": [
        {
          "author": "John Doe",
          "id": 3,
          "published": "2024-01-01T00:00:00.0000+00:00",
          "title": "The Book"
        },
        {
          "author": "Jane Doe",
          "id": 4,
          "published": "2024-01-01T00:00:00.0000+00:00",
          "title": "The Book 2"
        }
      ]
    }

Let’s get started!

Quick Start

View Demos